@@ -8,9 +8,10 @@ use std::{
 };
 
 use rust_embed::RustEmbed;
+use tempfile::NamedTempFile;
 use thiserror::Error;
 
-use crate::{tempfile::TempFile, RUSTC_COLOR_ARGS};
+use crate::RUSTC_COLOR_ARGS;
 
 /// `Output` contains stdout and stderr strings of some executed process.
 #[derive(Debug, Clone)]
@@ -70,11 +71,14 @@ pub enum RunError {
 ///
 /// If `rustc` exited with non-zero status, it is assumed to be a
 /// compilation IO error [`CompileError::IOError`] which is then returned.
-pub fn compile(path: impl AsRef<Path>) -> Result<TempFile, CompileError> {
-    let temp_file = TempFile::create();
+pub fn compile(path: impl AsRef<Path>) -> Result<NamedTempFile, CompileError> {
+    let temp_file = NamedTempFile::new()?;
+    dbg!(&temp_file);
     let cmd_output = Command::new("rustc")
         .args(&[
             "--test",
+            "--edition",
+            "2021",
             path.as_ref().to_str().unwrap(),
             "-o",
             temp_file.path().as_os_str().to_str().unwrap(),
@@ -166,13 +170,4 @@ mod tests {
             unreachable!();
         }
     }
-
-    #[test]
-    fn should_delete_temp_file() {
-        let compiled_handle = compile("tests/fixture/compileSuccess.rs").unwrap();
-        let path = compiled_handle.path().clone();
-        assert!(path.exists());
-        drop(compiled_handle);
-        assert!(!path.exists());
-    }
 }
