@@ -129,6 +129,7 @@ fn main() -> anyhow::Result<()> {
                                 break;
                             }
                             Key::Enter => {
+                                // TODO by pressing enter, otarustlings should start watching the next exercise
                                 // TODO call state.get_next_exercise(exercise)
                             }
                             _ => {}
@@ -142,8 +143,8 @@ fn main() -> anyhow::Result<()> {
             });
 
             let compile_state = Arc::clone(&state);
-            let _todo_fix_compile_handle: JoinHandle<anyhow::Result<()>> = thread::spawn(
-                move || {
+            let _todo_fix_compile_handle: JoinHandle<anyhow::Result<()>> =
+                thread::spawn(move || {
                     // Move a clone of the Arc to this closure
                     let state = compile_state;
                     let mut current_exercise = None::<Exercise>;
@@ -152,13 +153,13 @@ fn main() -> anyhow::Result<()> {
 
                     loop {
                         match receiver.recv().unwrap() {
-                            Message::Notify(b) => {
-                                if let Some(a) = &current_exercise {
+                            Message::Notify(changed_path) => {
+                                if let Some(current_exercise) = &current_exercise {
                                     if std::env::current_dir()
                                         .unwrap()
                                         .join("exercises")
-                                        .join(&a.path)
-                                        == b
+                                        .join(&current_exercise.path)
+                                        == changed_path
                                     {
                                         sender.send(Message::TestExercise)?;
                                     }
@@ -194,11 +195,11 @@ fn main() -> anyhow::Result<()> {
                                             .path,
                                     ),
                                 ) {
-                                    Ok(tempfile) => match run(tempfile) {
+                                    Ok(tempfile) => match run(tempfile.into_temp_path()) {
                                         Ok(output) => {
                                             term.clear_screen().unwrap();
                                             println!("{}", output.stdout.replace('\n', "\r\n"));
-                                            println!("Press Q to return to menu.\r");
+                                            println!("::: Well done! Press Q to return to menu.\r");
 
                                             {
                                                 let mut state = state.lock().unwrap();
@@ -234,8 +235,8 @@ fn main() -> anyhow::Result<()> {
                                     }
                                 }
                             }
-                            Message::SelectExercise(b) => {
-                                current_exercise = Some(b);
+                            Message::SelectExercise(e) => {
+                                current_exercise = Some(e);
                             }
                             Message::ExitExercise => {
                                 current_exercise = None;
@@ -247,8 +248,7 @@ fn main() -> anyhow::Result<()> {
                             }
                         }
                     }
-                },
-            );
+                });
 
             input_handle.join().unwrap()?;
         }
