@@ -38,6 +38,7 @@ impl Display for Status {
     }
 }
 
+/// An [`Item`] represents an item in the menu
 pub trait Item {
     fn file_name(&self) -> &str;
 
@@ -124,9 +125,6 @@ where
     theme: &'menu dyn Theme,
 }
 
-// FIXME
-unsafe impl<T> std::marker::Send for Menu<'_, T> where T: Item + PartialEq + fmt::Debug {}
-
 impl<'menu, T> Menu<'menu, T>
 where
     T: Item + PartialEq + fmt::Debug,
@@ -202,12 +200,12 @@ where
             term.flush()?;
 
             // TODO implement actions elsewhere
+            // let (next_sel, should_clear) = get_next_sel(term.read_key()?)?;
             match term.read_key()? {
                 Key::ArrowDown | Key::Tab | Key::Char('j') => {
                     if sel == !0 {
                         sel = 0;
                     } else {
-                        // TODO len of all exercises
                         sel = (sel + 1) % self.items.len();
                     }
                 }
@@ -242,6 +240,7 @@ where
     }
 }
 
+/// This renderer allows clearing all previously written lines
 pub struct TermRenderer<'term> {
     term: &'term Term,
     height: usize,
